@@ -1,7 +1,7 @@
 package PERLANCAR::File::HomeDir;
 
-our $DATE = '2017-01-04'; # DATE
-our $VERSION = '0.04'; # VERSION
+our $DATE = '2017-01-05'; # DATE
+our $VERSION = '0.05'; # VERSION
 
 use 5.010001;
 use strict;
@@ -38,7 +38,7 @@ sub get_my_home_dir {
 }
 
 # borrowed from File::HomeDir, with some modifications
-sub users_home {
+sub get_users_home_dir {
     my ($name) = @_;
 
     if ($^O eq 'MSWin32') {
@@ -77,7 +77,7 @@ PERLANCAR::File::HomeDir - Lightweight way to get current user's home directory
 
 =head1 VERSION
 
-This document describes version 0.04 of PERLANCAR::File::HomeDir (from Perl distribution PERLANCAR-File-HomeDir), released on 2017-01-04.
+This document describes version 0.05 of PERLANCAR::File::HomeDir (from Perl distribution PERLANCAR-File-HomeDir), released on 2017-01-05.
 
 =head1 SYNOPSIS
 
@@ -109,7 +109,7 @@ None are exported by default, but they are exportable.
 Try several ways to get home directory. Return undef or die (depends on
 C<$DIE_ON_FAILURE>) if everything fails.
 
-=head2 users_home($username) => str
+=head2 get_users_home_dir($username) => str
 
 =head1 HOMEPAGE
 
